// src/backend/simulationStatus.hh - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#ifndef SIMULATIONSTATUS_HH
#define SIMULATIONSTATUS_HH 1

#include "config.h"
#include <list>

#include "schedulable_status.hh"
#include "../templates/smartp.hh"

namespace sgpem
{
  class SimulationStatus;

  /** \brief Keeps informatios about the configuration of the simulation
					 
      Keeps informatios about the configuration of the simulation: which process is 
      running and other infos (since M02+)
  */
					 
  class SG_DLLEXPORT SimulationStatus
  {
  public:
    SimulationStatus();
    SimulationStatus(const SimulationStatus&);
		
    bool operator==(const SimulationStatus&) const;

    //this method isn't const because it returns a pointer which CAN alter the object!
    memory::smart_ptr<SchedulableStatus>        get_running();
    memory::smart_ptr<const SchedulableStatus>	get_running() const;
    void                                        set_running(SchedulableStatus);

  private:
    //I used a list instead of a vector because this one could reallocate the internal elements
    //making pointers returned by getRunning() point to nothing! SEGMENTATION-FAULT :-O
    std::list<SchedulableStatus> _set;
  };

}

#endif
